@@ -38,7 +38,7 @@ typedef struct _Dimension {
 } Dimension;
 
 enum State {
-    StateStart = 0, StatePlaying, StateStop, StateTerminate
+    StateStart = 0, StatePlaying, StateBufferPaused, StateStop, StateTerminate
 };
 
 static Display             *display;
@@ -69,19 +69,22 @@ static int                  seek_start;
 static guint                current_volume;
 static gboolean             has_video_codec;
 static enum State           current_state;
+static enum State           transition_state;
 
 static gboolean cb_play (gpointer data);
-static gboolean cb_buffering (gpointer data);
-static gboolean cb_playing (gpointer data);
-static gboolean cb_paused (gpointer data);
 static gboolean cb_position (gpointer data);
 static gboolean cb_stop (gpointer data);
-static gboolean cb_eos (gpointer data);
 static gboolean cb_error (gpointer data);
 static gboolean cb_finished (gpointer data);
 static gboolean cb_video_dimension (gpointer data);
 static gboolean cb_length (gpointer data);
 
+static void transitionFinished ()
+{
+    current_state = transition_state;
+    transition_state = StateStart;
+}
+
 static void output (const char *format, ...) {
     static gboolean need_cr;
     va_list vl;
@@ -217,6 +220,92 @@ static void gstGetDuration () {
         }
 }
 
+static void seek (int val /*offset_in_deciseconds*/, int abs) {
+    if (gst_elm_play)
+        gst_element_seek (gst_elm_play, 1.0, GST_FORMAT_TIME,
+                (GstSeekFlags) (GST_SEEK_FLAG_FLUSH | GST_SEEK_FLAG_KEY_UNIT),
+                abs ? GST_SEEK_TYPE_SET : GST_SEEK_TYPE_CUR,
+                val * GST_MSECOND * 100,
+                GST_SEEK_TYPE_NONE, GST_CLOCK_TIME_NONE);
+}
+
+static void bufferingMessage (guint percentage) {
+    if (current_state < StateStop) {
+        GstState state;
+        gst_element_get_state (gst_elm_play, &state, NULL, 0);
+        if (StateBufferPaused != transition_state &&
+                GST_STATE_PLAYING == state &&
+                percentage < 40) {
+            transition_state = StateBufferPaused;
+            gst_element_set_state (gst_elm_play, GST_STATE_PAUSED);
+            state = GST_STATE_PAUSED;
+        }
+        if (percentage >= 100 &&
+                StateBufferPaused == current_state &&
+                transition_state != StatePlaying) {
+            transition_state = StatePlaying;
+            gst_element_set_state (gst_elm_play, GST_STATE_PLAYING);
+        }
+        if (state != GST_STATE_PLAYING)
+            output ("\rCache fill: %d%", percentage);
+    }
+}
+
+static void stateChangeMessage (GstObject *src, GstState os,  GstState ns)
+{
+    if (GST_IS_ELEMENT (src)) {
+        GstElement *elm = GST_ELEMENT (src);
+
+        if (elm == gst_elm_play) {
+            if (os == GST_STATE_PAUSED && ns >= GST_STATE_PLAYING) {
+                if (StatePlaying == transition_state) {
+                    if (StateStart == current_state) {
+                        gstGetDuration ();
+                        if (!has_video_codec)
+                            output ("Video: no video\n");
+                        output ("\rA:0.0\rA:0.0");
+                        if (seek_start > 0)
+                            seek (seek_start * 10, 1);
+                    } else {
+                        output ("\rCache fill: 100%");
+                    }
+                    transitionFinished ();
+                }
+                if (!position_tag)
+                    position_tag = g_timeout_add (500, cb_position, NULL);
+            } else if (os >= GST_STATE_PAUSED && ns <= GST_STATE_READY) {
+                g_idle_add (cb_stop, NULL);
+            } else if (ns == GST_STATE_PAUSED) {
+                if (os > GST_STATE_PAUSED) {
+                    if (StateBufferPaused == transition_state)
+                        transitionFinished ();
+                    else
+                        output ("ID_PAUSED\n");
+                } else if (StatePlaying == transition_state) {
+                    gst_element_set_state (gst_elm_play, GST_STATE_PLAYING);
+                }
+            }
+        } else if (os == GST_STATE_PAUSED &&
+                ns >= GST_STATE_PLAYING &&
+                StateStart == current_state) {
+            gchar *name = gst_object_get_name (src);
+            fprintf (stderr, "%s changed to PLAYING\n", name);
+            if (!has_video_codec && !strcmp (name, "videosink")) {
+                GstPad *pad;
+                has_video_codec = TRUE;
+                pad = gst_element_get_static_pad (elm, "sink");
+                if (!pad)
+                    pad = gst_element_get_request_pad (elm, "sink");
+                if (pad) {
+                    gstCapsSet (pad, NULL, NULL);
+                    g_object_unref (G_OBJECT (pad));
+                }
+            }
+            g_free (name);
+        }
+    }
+}
+
 /*static void
 cb_expose (GtkWidget * w, GdkEventExpose * ev, GstElement * e)
 {
@@ -277,12 +366,12 @@ static void gstBusMessage (GstBus *bus, GstMessage *message, gpointer data) {
         }
         case GST_MESSAGE_EOS:
             fprintf (stderr, "eos msg\n");
-            g_idle_add (cb_eos, NULL);
+            g_idle_add (cb_stop, NULL);
             break;
         case GST_MESSAGE_BUFFERING: {
             gint percent = 0;
             gst_structure_get_int (message->structure, "buffer-percent", &percent);
-            g_idle_add (cb_buffering, (void *) (long) percent);
+            bufferingMessage (percent);
             break;
         }
         case GST_MESSAGE_APPLICATION: {
@@ -294,39 +383,7 @@ static void gstBusMessage (GstBus *bus, GstMessage *message, gpointer data) {
         case GST_MESSAGE_STATE_CHANGED: {
             GstState old_state, new_state;
             gst_message_parse_state_changed(message, &old_state, &new_state,0L);
-            if (GST_IS_ELEMENT (message->src)) {
-                if (GST_ELEMENT (message->src) == gst_elm_play) {
-                    if (old_state == GST_STATE_PAUSED &&
-                            new_state >= GST_STATE_PLAYING) {
-                        gstGetDuration ();
-                        g_idle_add (cb_playing, NULL);
-                    } else if (old_state >= GST_STATE_PAUSED &&
-                            new_state <= GST_STATE_READY) {
-                        g_idle_add (cb_stop, NULL);
-                    } else if (old_state > GST_STATE_PAUSED &&
-                            new_state == GST_STATE_PAUSED) {
-                        g_idle_add (cb_paused, NULL);
-                    }
-                } else if (old_state == GST_STATE_PAUSED &&
-                        new_state >= GST_STATE_PLAYING) {
-                    gchar *name = gst_object_get_name (GST_OBJECT (message->src));
-                    fprintf (stderr, "%s changed to PLAYING\n", name);
-                    if (!has_video_codec && !strcmp (name, "videosink")) {
-                        GstPad *pad;
-                        has_video_codec = TRUE;
-                        pad = gst_element_get_static_pad (
-                                GST_ELEMENT (message->src), "sink");
-                        if (!pad)
-                            pad = gst_element_get_request_pad (
-                                    GST_ELEMENT (message->src), "sink");
-                        if (pad) {
-                            gstCapsSet (pad, NULL, NULL);
-                            g_object_unref (G_OBJECT (pad));
-                        }
-                    }
-                    g_free (name);
-                }
-            }
+            stateChangeMessage (message->src, old_state, new_state);
             break;
         }
         case GST_MESSAGE_DURATION:
@@ -337,6 +394,7 @@ static void gstBusMessage (GstBus *bus, GstMessage *message, gpointer data) {
         case GST_MESSAGE_NEW_CLOCK:
         case GST_MESSAGE_STATE_DIRTY:
         case GST_MESSAGE_STREAM_STATUS:
+        case GST_MESSAGE_ASYNC_DONE:
              break;
         default:
              fprintf (stderr, "Unhandled msg %s (0x%x)\n",
@@ -546,11 +604,8 @@ static void play () {
         }
         g_object_set (gst_elm_play, "suburi", sub_mrl, NULL);
     }
+    transition_state = StatePlaying;
     gst_element_set_state (gst_elm_play, GST_STATE_PAUSED);
-    if (gstPollForStateChange (gst_elm_play, GST_STATE_PAUSED, GST_SECOND/2)) {
-        gst_element_set_state (gst_elm_play, GST_STATE_PLAYING);
-        gstPollForStateChange (gst_elm_play, GST_STATE_PLAYING, GST_SECOND/2);
-    }
     return;
 fail:
     if (videosink) {
@@ -566,7 +621,8 @@ fail:
 
 static void pause () {
     if (gst_elm_play) {
-        GstState state = GST_STATE (gst_elm_play) == GST_STATE_PLAYING ?
+        GstState playbin_state = GST_STATE (gst_elm_play);
+        GstState state = playbin_state == GST_STATE_PLAYING ?
             GST_STATE_PAUSED : GST_STATE_PLAYING;
 
         if (position_tag) {
@@ -574,8 +630,29 @@ static void pause () {
             position_tag = 0;
         }
 
+        if (StateBufferPaused == current_state) {
+            /*StateBufferPaused: kmplayer in playing state*/
+            current_state = StatePlaying;
+            if (StateStart == transition_state)
+                /*done with setting to 'normal' pause state*/
+                return;
+            if (StatePlaying == transition_state) {
+                /* pause a not yet signaled playing state */
+                state = GST_STATE_PAUSED;
+                transition_state = StateStart;
+            }
+        } else if (StateBufferPaused == transition_state) {
+            /* also done in playing state, so we're pausing */
+            transition_state = StateStart;
+            return;
+        } else if (StatePlaying == transition_state) {
+            /* block auto transition to playing state */
+            transition_state = StateStart;
+            if (GST_STATE_PAUSED != playbin_state)
+                /* not yet in paused, so we're done */
+                return;
+        }
         gst_element_set_state (gst_elm_play, state);
-        gstPollForStateChange (gst_elm_play, state, GST_SECOND/2);
     }
 }
 
@@ -635,15 +712,6 @@ static void brightness (int b) {
     adjustColorSetting ("BRIGHTNESS", b);
 } */
 
-static void seek (int val /*offset_in_deciseconds*/, int abs) {
-    if (gst_elm_play)
-        gst_element_seek (gst_elm_play, 1.0, GST_FORMAT_TIME,
-                (GstSeekFlags) (GST_SEEK_FLAG_FLUSH | GST_SEEK_FLAG_KEY_UNIT),
-                abs ? GST_SEEK_TYPE_SET : GST_SEEK_TYPE_CUR,
-                val * GST_MSECOND * 100,
-                GST_SEEK_TYPE_NONE, GST_CLOCK_TIME_NONE);
-}
-
 static void volume (int val) {
     if (val >= 0 && val <= 100 && gst_elm_play) {
         current_volume = val;
@@ -719,46 +787,14 @@ static gboolean cb_play (gpointer data) {
     return FALSE;
 }
 
-static gboolean cb_buffering (gpointer data) {
-    GstState state;
-    (void)data;
-
-    if (current_state < StateStop) {
-        gst_element_get_state (gst_elm_play, &state, NULL, 0);
-        if (state != GST_STATE_PLAYING)
-            output ("\rCache fill: %d%", (long) data);
-    }
-    return FALSE;
-}
-
-static gboolean cb_playing (gpointer data) {
-    (void)data;
-    if (current_state < StateStop) {
-        if (current_state < StatePlaying) {
-            current_state = StatePlaying;
-            if (!has_video_codec)
-                output ("Video: no video\n");
-            output ("\rA:0.0\rA:0.0");
-            if (seek_start > 0)
-                seek (seek_start * 10, 1);
-        } else {
-            output ("\rCache fill: 100%");
-        }
-        if (!position_tag)
-            position_tag = g_timeout_add (500, cb_position, NULL);
-    }
-    return FALSE;
-}
-
-static gboolean cb_paused (gpointer data) {
-    (void)data;
-    output ("ID_PAUSED\n");
-    return FALSE;
-}
-
 static gboolean cb_position (gpointer data) {
     gboolean ret;
     gint64 val = 0; /* usec */
+
+    if (StateBufferPaused == current_state ||
+            StateBufferPaused == transition_state)
+        return TRUE;
+
     if (!position_tag) {
         fprintf(stderr, "cb_position  tag:%u\n", position_tag);
         return FALSE;
@@ -790,12 +826,6 @@ static gboolean cb_stop (gpointer data) {
     return FALSE;
 }
 
-static gboolean cb_eos (gpointer data) {
-    (void)data;
-    stop ();
-    return FALSE;
-}
-
 static gboolean cb_error (gpointer data) {
     (void)data;
     stop ();
@@ -814,7 +844,9 @@ static gboolean cb_finished (gpointer data) {
         if (gst_bus_async)
             g_signal_handler_disconnect (gst_bus, gst_bus_async);
         gst_object_unref (gst_bus);
-        gst_object_unref (GST_OBJECT (gst_elm_play));
+        if (StatePlaying != transition_state)
+            /* work around crash in libpulse.so.0(pa_context_disconnect */
+            gst_object_unref (GST_OBJECT (gst_elm_play));
         gst_bus = 0L;
         gst_elm_play = 0L;
         color_balance = 0L;
@@ -940,6 +972,8 @@ int main (int argc, char **argv) {
             ao_driver = argv [++i];
         } else if (!strcmp (argv [i], "-vo")) {
             vo_driver = argv [++i];
+        } else if (!strcmp (argv [i], "-sub") && ++i < argc) {
+            sub_mrl = g_strdup (argv [i]);
         } else if (!strcmp (argv [i], "-dvd-device") && ++i < argc) {
             dvd_device = argv [i];
         } else if (!strcmp (argv [i], "-vcd-device") && ++i < argc) {
