@@ -140,8 +140,13 @@ void app_set_playing (Application *app, int p) {
         gtk_widget_show (GTK_WIDGET (app->tb_next));
         gtk_widget_hide (GTK_WIDGET (app->tb_save));
         gtk_widget_show (GTK_WIDGET (app->tb_stop));
-        gtk_widget_show (GTK_WIDGET (app->tb_progress));
-        gtk_widget_hide (GTK_WIDGET (app->tb_location));
+        if (app->show_progress || app->fullscreen) {
+            gtk_widget_show (GTK_WIDGET (app->tb_progress));
+            gtk_widget_hide (GTK_WIDGET (app->tb_location));
+        } else {
+            gtk_widget_hide (GTK_WIDGET (app->tb_progress));
+            gtk_widget_show (GTK_WIDGET (app->tb_location));
+        }
         gtk_widget_hide (GTK_WIDGET (app->tb_go));
     } else {
         gtk_widget_hide (GTK_WIDGET (app->tb_pause));
@@ -171,6 +176,7 @@ void app_full_screen (Application *app) {
         gtk_widget_hide (app->info_area);
         gtk_widget_hide (app->playlist_area);
         gtk_widget_hide (app->toolbar_area);
+        app_set_playing (app, app->playing);
         gtk_fixed_move (GTK_FIXED(app->window_area), app->toolbar_area, 0, 410);
         gtk_widget_show (GTK_WIDGET (app->tb_favorites));
         gtk_window_fullscreen (app->window);
@@ -189,6 +195,7 @@ void app_normal_screen (Application *app) {
         gtk_widget_hide (app->title_area);
         gtk_widget_hide (GTK_WIDGET (app->tb_favorites));
         gtk_fixed_move (GTK_FIXED(app->window_area), app->toolbar_area, 0, 354);
+        app_set_playing (app, app->playing);
         gtk_widget_show (app->toolbar_area);
         if (app->controls_timer) {
             g_source_remove (app->controls_timer);
