@@ -44,6 +44,13 @@ KMPLAYER_NO_EXPORT Node *ASX::Asx::childFromTag (const String & tag) {
     return NULL;
 }
 
+void *ASX::Asx::role (RoleType msg, void *content)
+{
+    if (RolePlaylist == msg)
+        return !title.isEmpty () ? (PlaylistRole *) this : NULL;
+    return Mrl::role (msg, content);
+}
+
 KDE_NO_EXPORT Node::PlayType ASX::Asx::playType () {
     if (cached_ismrl_version != document ()->m_tree_version)
         for (Node *e = firstChild (); e; e = e->nextSibling ()) {
@@ -137,8 +144,12 @@ KMPLAYER_NO_EXPORT void ASX::Entry::deactivate () {
     Mrl::deactivate ();
 }
 
-KMPLAYER_NO_EXPORT bool ASX::Entry::expose () const {
-    return ref_child_count > 1 && !title.isEmpty ();
+void *ASX::Entry::role (RoleType msg, void *content)
+{
+    if (RolePlaylist == msg)
+        return ref_child_count > 1 && !title.isEmpty ()
+            ? (PlaylistRole *) this : NULL;
+    return Mrl::role (msg, content);
 }
 
 //-----------------------------------------------------------------------------
@@ -148,10 +159,6 @@ KMPLAYER_NO_EXPORT void ASX::Ref::opened () {
     Mrl::opened ();
 }
 
-KMPLAYER_NO_EXPORT bool ASX::Ref::expose () const {
-    return !src.isEmpty ();
-}
-
 //-----------------------------------------------------------------------------
 
 KMPLAYER_NO_EXPORT void ASX::EntryRef::opened () {
