@@ -52,7 +52,7 @@ public:
     KDE_NO_CDTOR_EXPORT Playlist (NodePtr & d) : Mrl (d, id_node_playlist) {}
     Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "playlist"; }
-    bool expose () const { return !title.isEmpty (); }
+    void *role (RoleType msg, void *content=NULL);
     void closed ();
 };
 
@@ -61,19 +61,15 @@ public:
     KDE_NO_CDTOR_EXPORT Tracklist (NodePtr & d) : Element (d, id_node_tracklist) {}
     Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "tracklist"; }
-    bool expose () const { return false; }
 };
 
-class KMPLAYER_NO_EXPORT Track : public Mrl {
+class KMPLAYER_NO_EXPORT Track : public Element {
 public:
-    KDE_NO_CDTOR_EXPORT Track (NodePtr & d) : Mrl (d, id_node_track) {}
+    KDE_NO_CDTOR_EXPORT Track (NodePtr & d) : Element (d, id_node_track) {}
     void closed ();
     void activate ();
-    PlayType playType ();
-    Mrl * linkNode ();
     KDE_NO_EXPORT const char * nodeName () const { return "track"; }
     Node *childFromTag (const String & tag);
-    NodePtrW location;
 };
 
 class KMPLAYER_NO_EXPORT Location : public Mrl {
@@ -81,7 +77,6 @@ public:
     KDE_NO_CDTOR_EXPORT Location (NodePtr &d) : Mrl (d, id_node_location) {}
     KDE_NO_EXPORT const char * nodeName () const { return "location"; }
     void closed ();
-    bool expose () const { return false; }
 };
 
 } //namespace XSPF
