@@ -827,6 +827,10 @@ void Control::stateChanged (Process * p, Process::State os, Process::State ns) {
         addRecent (playlist_data->document->mrl()->src,
                 playlist_data->document->document ()->caption ());
         updatePlayTree (m_app);
+        if (mrl->audio_only &&
+                playlist_data->current &&
+                playlist_data->current->id != SMIL::id_node_smil)
+            app_normal_screen (m_app);
         app_update_screen_blanking (m_app);
     }
 }
@@ -927,15 +931,8 @@ void Control::setPosition (int p) {
 void Control::setLength (int len) {
     hildon_seekbar_set_total_time (HILDON_SEEKBAR (m_app->progress_bar), len);
     hildon_seekbar_set_fraction (HILDON_SEEKBAR (m_app->progress_bar), len);
-    if (len > 50) {
-        gtk_widget_hide (GTK_WIDGET (m_app->tb_location));
-        gtk_widget_hide (GTK_WIDGET (m_app->tb_go));
-        gtk_widget_show (GTK_WIDGET (m_app->tb_progress));
-    } else {
-        gtk_widget_show (GTK_WIDGET (m_app->tb_location));
-        gtk_widget_show (GTK_WIDGET (m_app->tb_go));
-        gtk_widget_hide (GTK_WIDGET (m_app->tb_progress));
-    }
+    m_app->show_progress = len > 50;
+    app_set_playing (m_app, m_app->playing);
 }
 
 void Control::setAspect (float aspect) {
