@@ -576,13 +576,23 @@ cb_hildon_row_tapped (GtkTreeView *view, GtkTreePath *path, Application *app)
                 if (pld->id == 0 || pld->edit_mode)
                     setInfoContent (app, node, pld->edit_mode);
                 if (!had_selection_change &&
-                        !pld->edit_mode &&
-                        (pld->id == 0 || (node && node->mrl ()))) {
-                    if (pld->id > 0) {
-                        pld->current = node;
-                        g_idle_add ((GSourceFunc) delayedJump, (gpointer) app);
-                    } else {
-                        jump (node, CONTROL(app));
+                        !pld->edit_mode) {
+                    bool do_jump = node->isPlayable ();
+                    if (!do_jump && node->mrl () && node->firstChild ()) {
+                        // ugly, but for inline SMIL we need it
+                        GtkTreeView *view = GTK_TREE_VIEW (app->playlist_view);
+                        GtkTreeModel *model = gtk_tree_view_get_model (view);
+                        GtkTreeIter iter;
+                        if (gtk_tree_model_get_iter (model, &iter, path))
+                            do_jump = !gtk_tree_model_iter_has_child (model, &iter);
+                    }
+                    if (do_jump) {
+                        if (pld->id > 0) {
+                            pld->current = node;
+                            g_idle_add ((GSourceFunc) delayedJump, (gpointer) app);
+                        } else {
+                            jump (node, CONTROL(app));
+                        }
                     }
                 } else {
                     had_selection_change = false;
