@@ -625,9 +625,11 @@ KMPLAYER_NO_EXPORT void MPlayer::writeEvent (UnixProcess *) {
     if (nr < data.length ()) {
         //debugLog () << "partial " << nr << " " << data.length() << endl;
         command_chunk = String (((const char*) data) + nr);
-    } else if (!commands.size ()) {
-        // FIXME: always remove and readd when new data from stdin arrives
-        unix_process.pollStdIn (false);
+    } else {
+        command_chunk.clear ();
+        if (!commands.size ())
+            // FIXME: always remove and readd when new data from stdin arrives
+            unix_process.pollStdIn (false);
     }
 }
 
