@@ -829,14 +829,14 @@ void *nppInstanceOpen (const char *mime, uint16_t argc, char *argn[],
     int screen;
     int i;
     int needs_xembed;
-    unsigned int width = 0, height = 0;
+    /*unsigned int width = 0, height = 0;*/
 
     browser_data = ndata;
     browser_notify = notify;
 
     npp = (NPP_t*)nsAlloc (sizeof (NPP_t));
     memset (npp, 0, sizeof (NPP_t));
-    for (i = 0; i < argc; i++) {
+    /*for (i = 0; i < argc; i++) {
         print ("arg %s %s\n", argn[i], argv[i]);
         if (!strcasecmp (argn[i], "width"))
             width = strtol (argv[i], 0L, 10);
@@ -844,7 +844,7 @@ void *nppInstanceOpen (const char *mime, uint16_t argc, char *argn[],
             height = strtol (argv[i], 0L, 10);
     }
     if (width > 0 && height > 0)
-        notify->setDimension (ndata, width, height);
+        notify->setDimension (ndata, width, height);*/
 
     np_err = np_funcs.newp (mime, npp, NP_EMBED, argc, argn, argv, saved_data);
     if (np_err != NPERR_NO_ERROR) {
