@@ -222,7 +222,7 @@ CairoPaintVisitor::CairoPaintVisitor (ViewArea *v, cairo_surface_t *cs,
         cairo_set_tolerance (cr, 0.5 );
         cairo_set_antialias (cr, CAIRO_ANTIALIAS_NONE);
         //cairo_push_group (cr);
-        cairo_set_source_rgb (cr, 16.0 / 255, 24.0 / 255, 24.0 / 255);
+        cairo_set_source_rgb (cr, 8.0 / 255, 12.0 / 255, 12.0 / 255);
         cairo_rectangle (cr, rect.x(), rect.y(), rect.width(), rect.height());
         cairo_fill (cr);
 #endif
@@ -2353,67 +2353,35 @@ void cb_view_area_realized (GtkWidget *widget, Application * app) {
     //        GTK_SIGNAL_FUNC (cb_view_area_configure), app);
     gtk_widget_set_double_buffered (widget, false);
     gtk_widget_set_app_paintable (widget, true);
-    Color c (0x101818);
+    Color c (0x080C0C);
     gdk_window_set_background (widget->window, (GdkColor *) c);
     VIEWAREA(app)->setOutputWidget (app, widget);
 }
 
-static GdkBitmap *createControlsMask () {
-    cairo_surface_t *surface = cairo_image_surface_create (CAIRO_FORMAT_A1, 800, 60);
-    cairo_t *cr = cairo_create (surface);
+/*void videoStopRealized (GtkWidget *widget, gpointer p)
+{
+    cairo_surface_t *s = cairo_image_surface_create (CAIRO_FORMAT_A1, 70, 70);
+    cairo_t *cr = cairo_create (s);
     cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
     cairo_set_source_rgb (cr, 1, 1, 1);
 
     cairo_new_path (cr);
-    cairo_move_to (cr, 30, 30);
-    cairo_line_to (cr, 90, 0);
-    cairo_curve_to (cr, 90 - 12, 20, 90 - 12, 40, 90, 60);
-    cairo_line_to (cr, 30, 30);
-    cairo_close_path (cr);
-    cairo_fill (cr);
-
-    cairo_new_path (cr);
-    cairo_move_to (cr, 130, 0);
-    cairo_line_to (cr, 650, 0);
-    cairo_curve_to (cr, 650 - 12, 20, 650 - 12, 40, 650, 60);
-    cairo_line_to (cr, 130, 60);
-    cairo_curve_to (cr, 130 - 12, 40, 130 - 12, 20, 130, 0);
-    cairo_close_path (cr);
-    cairo_fill (cr);
-
-    cairo_new_path (cr);
-    cairo_move_to (cr, 710, 0);
-    cairo_line_to (cr, 770, 30);
-    cairo_line_to (cr, 710, 60);
-    cairo_curve_to (cr, 710 + 12, 40, 710 + 12, 20, 710, 0);
-    cairo_close_path (cr);
-    cairo_fill (cr);
-
-    cairo_translate (cr, 680, 12);
-    cairo_new_path (cr);
-    for (int i = 0; i < 6; ++i) {
-        cairo_rotate (cr, 60 * M_PI / 180);
-        cairo_line_to (cr, 0, -8);
-        cairo_translate (cr, 0, -8);
-        cairo_rotate (cr, 60 * M_PI / 180);
-        cairo_line_to (cr, 0, -8);
-        cairo_translate (cr, 0, -8);
-        cairo_rotate (cr, 60 * M_PI / 180);
-        cairo_line_to (cr, 0, -8);
-        cairo_translate (cr, 0, -8);
-        cairo_rotate (cr, 240 * M_PI / 180);
-    }
+    cairo_move_to (cr, 0, 0);
+    cairo_line_to (cr, 70, 0);
+    cairo_line_to (cr, 70, 70);
+    cairo_line_to (cr, 20, 70);
+    cairo_curve_to (cr, 5, 70, 0, 65, 0, 50);
     cairo_close_path (cr);
     cairo_fill (cr);
 
     GdkBitmap *bitmap = gdk_bitmap_create_from_data (NULL,
-            (const gchar *) cairo_image_surface_get_data (surface), 800, 60);
+            (const gchar *) cairo_image_surface_get_data (s), 70, 70);
 
     cairo_destroy (cr);
-    cairo_surface_destroy (surface);
+    cairo_surface_destroy (s);
 
-    return bitmap;
-}
+    gtk_widget_shape_combine_mask (widget, bitmap, 0, 0);
+}*/
 
 gboolean cb_scheduledPaint (void * vp) {
 #ifdef DEBUG_TIMERS
